﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion


using System.Collections.Generic;
using System.Linq;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.DataPreprocessing.Transformations;
using HeuristicLab.Parameters;
namespace HeuristicLab.DataPreprocessing.Implementations.Transformations {
  [Item("LinearTransformation", "Represents a linear transformation with multiplication and addition.")]
  public class LinearTransformation : Transformation<double> {

    #region Parameters
    public IValueParameter<DoubleValue> MultiplicandParameter {
      get { return (IValueParameter<DoubleValue>)Parameters["Multiplicand"]; }
    }
    public IValueParameter<DoubleValue> SummandParameter {
      get { return (IValueParameter<DoubleValue>)Parameters["Summand"]; }
    }
    #endregion

    public LinearTransformation()
      : base() {
      Parameters.Add(new ValueParameter<DoubleValue>("Multiplicand", "Multiplicand for linear transformation", new DoubleValue(1.0)));
      Parameters.Add(new ValueParameter<DoubleValue>("Summand", "Summand for linear transformation", new DoubleValue(0.0)));
    }

    public override IEnumerable<double> Apply(IEnumerable<double> data) {
      return data.Select(e => e * MultiplicandParameter.Value.Value + SummandParameter.Value.Value).ToList();
    }

    public override IEnumerable<double> InverseApply(IEnumerable<double> data) {
      throw new System.NotImplementedException();
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      throw new System.NotImplementedException();
    }

    public override void Check(IEnumerable<double> data) {
      throw new System.NotImplementedException();
    }
  }
}
